@@ -37,10 +37,10 @@ sub _my_sort {
 sub choose_videos {
     my ( $opt, $info, $tmp, $ex, $prompt ) = @_;
     my $regexp;
-    my $back   = '       BACK';
-    my $filter = '     FILTER';
-    my $sort   = '       SORT';
-    my $enter  = '      ENTER';
+    my $back   = sprintf "%*s", $opt->{length_video_id}, '   BACK';
+    my $filter = sprintf "%*s", $opt->{length_video_id}, ' FILTER';
+    my $sort   = sprintf "%*s", $opt->{length_video_id}, '   SORT';
+    my $enter  = sprintf "%*s", $opt->{length_video_id}, '  ENTER';
     my %chosen_video_ids;
     my @last_chosen_video_ids = ();
 
@@ -72,11 +72,17 @@ sub choose_videos {
                 $title = decode( 'console_out', $title );
             }
             if ( $opt->{list_sort_item} eq 'view_count_raw' || $opt->{show_view_count} ) {
-                push @videos, sprintf "%11s | %7s  %10s  %$opt->{length_view_count}s  %s", $video_id,
-                    $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date}, $tmp->{$ex}{$video_id}{view_count}, $title;
+                push @videos, sprintf "%*s | %7s  %10s  %*s  %s",
+                        $opt->{length_video_id}, $video_id,
+                        $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date},
+                        $opt->{length_view_count}, $tmp->{$ex}{$video_id}{view_count},
+                        $title;
             }
             else {
-                push @videos, sprintf "%11s | %7s  %10s  %s", $video_id, $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date}, $title;
+                push @videos, sprintf "%*s | %7s  %10s  %s",
+                        $opt->{length_video_id}, $video_id,
+                        $tmp->{$ex}{$video_id}{duration}, $tmp->{$ex}{$video_id}{upload_date},
+                        $title;
             }
             push @tmp_video_ids, $video_id;
             $index++;
