@@ -89,6 +89,7 @@ sub json_to_hash {
             $tmp->{$ex}{$video_id}{$key} = $h_ref->{$key};
         }
     }
+    $tmp->{$ex}{$video_id}{video_id} = $video_id;
     if ( $tmp->{$ex}{$video_id}{upload_date} && $tmp->{$ex}{$video_id}{upload_date} =~ /^(\d{4})(\d{2})(\d{2})\z/ ) {
         $tmp->{$ex}{$video_id}{upload_date}     = $1 . '-' . $2 . '-' . $3;
         $tmp->{$ex}{$video_id}{upload_datetime} = $1 . '-' . $2 . '-' . $3 . 'T00:00:00';
@@ -101,6 +102,7 @@ sub json_to_hash {
 
 sub _prepare_info {
     my ( $opt, $info, $ex, $video_id ) = @_;
+    $opt->{length_video_id} = length $video_id if length $video_id > $opt->{length_video_id};
     $info->{$ex}{$video_id}{title}           ||= time();
     $info->{$ex}{$video_id}{duration}        ||= '-:--:--';
     $info->{$ex}{$video_id}{upload_date}     ||= '0000-00-00';
