@@ -21,8 +21,8 @@ use Try::Tiny              qw( try catch );
 
 use if $^O eq 'MSWin32', 'Win32::Console::ANSI';
 
-use App::YTDL::Helper       qw( write_json read_json uni_capture HIDE_CURSOR SHOW_CURSOR );
 use App::YTDL::ChooseVideos qw( set_sort_videolist );
+use App::YTDL::Helper       qw( write_json read_json uni_capture HIDE_CURSOR SHOW_CURSOR );
 
 
 
@@ -348,8 +348,8 @@ sub set_options {
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "merge_overwrite" ) {
-                my $prompt = '"ffmpeg": overwrite files without asking?';
-                my $list = [ qw( no yes ) ];
+                my $prompt = '\'ffmpeg\' - overwrite files';
+                my $list = [ qw( ask yes ) ];
                 _opt_choose_from_list_idx( $opt, $choice, $prompt, $list );
             }
             elsif ( $choice eq "merge_ext" ) {
